|
From: <fri...@us...> - 2009-02-27 09:03:00
|
Revision: 9678
http://zaf.svn.sourceforge.net/zaf/?rev=9678&view=rev
Author: friedelwolff
Date: 2009-02-27 09:02:55 +0000 (Fri, 27 Feb 2009)
Log Message:
-----------
Initial support for the qualificative (relative) mode. Still need to do all non-present tenses, but at least object morphemes, the progressive and potential morpheme is supported. Still need to verify that the potential morpheme can be used in the qualificative.
Modified Paths:
--------------
trunk/dict/zu/hunspell/zu_aff.py
Modified: trunk/dict/zu/hunspell/zu_aff.py
===================================================================
--- trunk/dict/zu/hunspell/zu_aff.py 2009-02-26 11:09:53 UTC (rev 9677)
+++ trunk/dict/zu/hunspell/zu_aff.py 2009-02-27 09:02:55 UTC (rev 9678)
@@ -30,7 +30,7 @@
#TODO: review class 1 exceptions
#TODO: handle negative future circumfixes with vowel verbs better
#TODO: be- and se- verbs
#TODO: non-indicative modes, positive and negative
#TODO: aspectual morphemes with non-indicative modes (+/-)
#TODO: exclusive aspectual morpheme (ka) with object morpheme?
#TODO: monosyllabic verbs
@@ -39,6 +39,10 @@
#TODO: consider avoiding illegal reflexives
#TODO: hortative particle words
#TODO: noun continuation class for infinitive+obj and negative infinitives?
+#TODO: negative qualificatives
+#TODO: qualificatives of non-present tenses
+#TODO: passives and all their consequences
+#TODO: consider doing -eka -ela -ana with rules
#NOUNS:
#TODO: possessive of class 1
@@ -50,9 +54,9 @@
subject_morphemes = ["ngi", "u", "si", "ni", "u", "ba", "i", "li", "a", "si", "zi", "lu", "bu", "ku"]
remote_past_subject_morphemes = ["nga", "wa", "sa", "na", "wa", "ba", "ya", "la", "a", "sa", "za", "lwa", "ba", "kwa"]
-relative_prefixes = ["engi", "esi", "eni", "o", "aba", "e", "eli", "a", "esi", "ezi", "olu", "obu", "oku"]
+qualificative_prefixes = ["engi", "esi", "eni", "o", "aba", "e", "eli", "a", "esi", "ezi", "olu", "obu", "oku"]
situative_prefixes = ["e", "be"]
-concords = subject_morphemes + relative_prefixes + situative_prefixes
+concords = subject_morphemes + qualificative_prefixes + situative_prefixes
object_morphemes = ["ngi", "ku", "si", "ni", "m", "ba", "wu", "yi", "li", "wa", "zi", "lu", "bu"]
possesive_morphemes = ["wa", "ba", "ya", "la", "sa", "za", "lwa", "kwa"]
#bu -> ba
@@ -438,6 +442,9 @@
question = aff.add_group(suffix=True, flag="i")
# This group contains rules for forming question words
+ qualificative_yo = aff.add_group(suffix=True, flag="y")
+ # This group contains rules for the qualificative -yo suffix
+
noun = aff.add_group(suffix=False, flag="N")
# This group will contain most prefixes for nouns
@@ -503,6 +510,10 @@
for morpheme in remote_past_subject_morphemes:
verb_rules(main_subjects, affix=morpheme, morphology="REMOTE_PAST_IND", continuation_classes=[question])
+ #qualificative mode (relative mode)
+ for morpheme in qualificative_prefixes:
+ verb_rules(main_subjects, affix=morpheme, morphology="RELATIVE/QUALIFICATIVE", continuation_classes=[question, qualificative_yo])
+
#indicative long form, present, positive
verb_rules(infixes, affix="ya", needaffix=True, morphology="PRESENT_IND_LONG", continuation_classes=[simple_subjects])
#progressive aspectual morpheme
@@ -616,6 +627,8 @@
question.add_rule(affix="elani", strip="a", condition="a", morphology="Q_PRESENT_why")
question.add_rule(affix="eleni", strip="a", condition="a", morphology="Q_PAST_why")
+ qualificative_yo.add_rule(affix="yo", morphology="QUALIFICATIVE_sfx")
+
### Locatives ###
for prefix, morphology in [
("e", "LOC_pfx"),
@@ -703,7 +716,7 @@
relative.add_rule(affix=morpheme, morphology="COPULATIVE")
relative.add_rule(affix=add_semivowels("a"+morpheme), morphology="NEG_COPULATIVE")
relative.add_rule(affix="aka", morphology="NEG_COPULATIVE")
- for morpheme in relative_prefixes:
+ for morpheme in qualificative_prefixes:
relative.add_rule(affix=morpheme, morphology="RELATIVE/QUALIFICATIVE")
relative.add_rule(affix=morpheme+"nge", morphology="NEG_RELATIVE/QUALIFICATIVE")
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
@@ -30,7 +30,7 @@
#TODO: handle negative future circumfixes with vowel verbs better
#TODO: be- and se- verbs
-#TODO: non-indicative modes, positive and negative
+#TODO: non-indicative modes, positive and negative (qualificative started)
#TODO: aspectual morphemes with non-indicative modes (+/-)
#TODO: exclusive aspectual morpheme (ka) with object morpheme?
|